@@ -32,9 +32,10 @@ import (
 )
 
 var (
-	quietFlag       bool
-	buildFormatFlag = flags.NewTemplateFlag("{{json .}}", flags.BuildOutput{})
-	buildOutputFlag string
+	quietFlag                  bool
+	defaultBuildFormatTemplate = "{{json .}}"
+	buildFormatFlag            = flags.NewTemplateFlag(defaultBuildFormatTemplate, flags.BuildOutput{})
+	buildOutputFlag            string
 )
 
 // NewCmdBuild describes the CLI command to build artifacts.
@@ -51,7 +52,7 @@ func NewCmdBuild() *cobra.Command {
 		WithCommonFlags().
 		WithFlags([]*Flag{
 			{Value: &quietFlag, Name: "quiet", Shorthand: "q", DefValue: false, Usage: "Suppress the build output and print image built on success. See --output to format output.", IsEnum: true},
-			{Value: buildFormatFlag, Name: "output", Shorthand: "o", Usage: "Used in conjunction with --quiet flag. " + buildFormatFlag.Usage()},
+			{Value: buildFormatFlag, Name: "output", Shorthand: "o", DefValue: defaultBuildFormatTemplate, Usage: "Used in conjunction with --quiet flag. " + buildFormatFlag.Usage()},
 			{Value: &buildOutputFlag, Name: "file-output", DefValue: "", Usage: "Filename to write build images to"},
 			{Value: &opts.DryRun, Name: "dry-run", DefValue: false, Usage: "Don't build images, just compute the tag for each artifact.", IsEnum: true},
 		}).
