@@ -18,7 +18,12 @@ package app
 
 import (
 	"context"
+	"fmt"
 	"io"
+	"os"
+
+	shell "github.com/kballard/go-shellquote"
+	"github.com/sirupsen/logrus"
 
 	"github.com/GoogleContainerTools/skaffold/cmd/skaffold/app/cmd"
 )
@@ -30,5 +35,14 @@ func Run(out, stderr io.Writer) error {
 	catchCtrlC(cancel)
 
 	c := cmd.NewSkaffoldCommand(out, stderr)
+	if cmdLine := os.Getenv("SKAFFOLD_CMDLINE"); cmdLine != "" && len(os.Args) == 1 {
+		parsed, err := shell.Split(cmdLine)
+		if err != nil {
+			return fmt.Errorf("SKAFFOLD_CMDLINE is invalid: %w", err)
+		}
+		// XXX logged before logrus.SetLevel is called in NewSkaffoldCommand's PersistentPreRunE
+		logrus.Debugf("Retrieving command line from SKAFFOLD_CMDLINE: %q", parsed)
+		c.SetArgs(parsed)
+	}
 	return c.ExecuteContext(ctx)
 }
