@@ -18,6 +18,7 @@ set -euo pipefail
 
 DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
 
+SECRET=${SECRET:-${DIR}/../secrets}
 BIN=${DIR}/bin
 STATIK=${BIN}/statik
 LICENSES=${BIN}/go-licenses
@@ -53,4 +54,9 @@ if ! [[ -f ${STATIK} ]]; then
     popd
 fi
 
+if [[ -d ${SECRET} ]]; then
+   echo "generating statik for secret"
+   cp -R ${SECRET} "${TMP_DIR}/secret"
+fi
+
 ${STATIK} -f -src=${TMP_DIR} -m -dest cmd/skaffold/app/cmd
