@@ -21,7 +21,6 @@ import (
 	"errors"
 	"fmt"
 	"net/http"
-	"os/exec"
 	"path/filepath"
 	"sort"
 	"strings"
@@ -206,16 +205,5 @@ func getMinikubeDockerEnv(minikubeProfile string) (map[string]string, error) {
 		env[kv[0]] = kv[1]
 	}
 
-	if found, _ := util.DetectWSL(); found {
-		// rewrite Unix path to Windows
-		cmd := exec.Command("wslpath", env["DOCKER_CERT_PATH"])
-		out, err := util.RunCmdOut(cmd)
-		if err == nil {
-			env["DOCKER_CERT_PATH"] = strings.TrimRight(string(out), "\n")
-		} else {
-			return nil, fmt.Errorf("can't run wslpath: %s", err)
-		}
-	}
-
 	return env, nil
 }
