@@ -18,15 +18,10 @@ package deploy
 
 import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/initializer/config"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/initializer/errors"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 )
 
-type Error string
-
-func (e Error) Error() string { return string(e) }
-
-const NoManifest = Error("one or more valid Kubernetes manifests are required to run skaffold")
-
 // Initializer detects a deployment type and is able to extract image names from it
 type Initializer interface {
 	// deployConfig generates Deploy Config for skaffold configuration.
@@ -59,7 +54,7 @@ func (c *cliDeployInit) GetImages() []string {
 
 func (c *cliDeployInit) Validate() error {
 	if len(c.cliKubernetesManifests) == 0 {
-		return NoManifest
+		return errors.NoManifestErr{}
 	}
 	return nil
 }
