@@ -31,7 +31,7 @@ import (
 	"go.opentelemetry.io/otel/sdk/metric/controller/push"
 
 	"github.com/GoogleContainerTools/skaffold/cmd/skaffold/app/cmd/statik"
-	"github.com/GoogleContainerTools/skaffold/proto"
+	"github.com/GoogleContainerTools/skaffold/proto/v1"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
@@ -51,6 +51,7 @@ func TestExportMetrics(t *testing.T) {
 		Version:           "vTest.0",
 		Arch:              "test arch",
 		OS:                "test os",
+		ConfigCount:       1,
 		Deployers:         []string{"test kubectl"},
 		Builders:          map[string]int{"docker": 1, "buildpacks": 1},
 		BuildDependencies: map[string]int{"docker": 1},
@@ -63,18 +64,36 @@ func TestExportMetrics(t *testing.T) {
 		Version:           "vTest.1",
 		Arch:              "test arch 2",
 		OS:                "test os 2",
-		PlatformType:      "test platform",
+		ConfigCount:       2,
+		PlatformType:      "test platform 1:test platform 2",
 		Deployers:         []string{"test helm", "test kpt"},
 		SyncType:          map[string]bool{"manual": true},
 		EnumFlags:         map[string]string{"test_run": "test_run_value"},
 		Builders:          map[string]int{"kustomize": 3, "buildpacks": 2},
 		BuildDependencies: map[string]int{"docker": 1},
+		HelmReleasesCount: 2,
 		DevIterations:     []devIteration{{"sync", 0}, {"build", 400}, {"build", 0}, {"sync", 200}, {"deploy", 0}},
 		ErrorCode:         proto.StatusCode_BUILD_CANCELLED,
 		StartTime:         startTime.Add(time.Hour * 24 * 30),
 		Duration:          time.Minute * 2,
 	}
-	devBuildBytes, _ := json.Marshal([]skaffoldMeter{buildMeter, devMeter})
+	debugMeter := skaffoldMeter{
+		Command:       "debug",
+		Version:       "vTest.2",
+		Arch:          "test arch 1",
+		OS:            "test os 2",
+		ConfigCount:   2,
+		PlatformType:  "test platform",
+		Deployers:     []string{"test helm", "test kpt"},
+		SyncType:      map[string]bool{"manual": true, "sync": true},
+		EnumFlags:     map[string]string{"test_run": "test_run_value"},
+		Builders:      map[string]int{"jib": 3, "buildpacks": 2},
+		DevIterations: []devIteration{{"build", 104}, {"build", 0}, {"sync", 0}, {"deploy", 1014}},
+		ErrorCode:     proto.StatusCode_BUILD_CANCELLED,
+		StartTime:     startTime.Add(time.Hour * 24 * 10),
+		Duration:      time.Minute * 4,
+	}
+	metersBytes, _ := json.Marshal([]skaffoldMeter{buildMeter, devMeter, debugMeter})
 	fs := &testutil.FakeFileSystem{
 		Files: map[string][]byte{
 			"/secret/keys.json": []byte(testKey),
@@ -95,7 +114,7 @@ func TestExportMetrics(t *testing.T) {
 		{
 			name:         "meter is appended to previously saved metrics",
 			meter:        devMeter,
-			savedMetrics: devBuildBytes,
+			savedMetrics: metersBytes,
 		},
 		{
 			name:                "meter does not re-save invalid metrics",
@@ -113,10 +132,15 @@ func TestExportMetrics(t *testing.T) {
 			meter:    devMeter,
 			isOnline: true,
 		},
+		{
+			name:     "test creating debug otel metrics",
+			meter:    debugMeter,
+			isOnline: true,
+		},
 		{
 			name:         "test otel metrics include offline metrics",
 			meter:        devMeter,
-			savedMetrics: devBuildBytes,
+			savedMetrics: metersBytes,
 			isOnline:     true,
 		},
 	}
@@ -226,6 +250,7 @@ func checkOutput(t *testutil.T, meters []skaffoldMeter, b []byte) {
 	errorCount := make(map[interface{}]int)
 	builders := make(map[interface{}]int)
 	buildDeps := make(map[interface{}]int)
+	helmReleases := make(map[interface{}]int)
 	devIterations := make(map[interface{}]int)
 	deployers := make(map[interface{}]int)
 	enumFlags := make(map[interface{}]int)
@@ -244,7 +269,7 @@ func checkOutput(t *testutil.T, meters []skaffoldMeter, b []byte) {
 		platform[meter.PlatformType]++
 
 		for k, v := range meter.EnumFlags {
-			n := FlagsPrefix + strings.ReplaceAll(k, "-", "_")
+			n := strings.ReplaceAll(k, "-", "_")
 			enumFlags[n+":"+v]++
 		}
 
@@ -256,7 +281,7 @@ func checkOutput(t *testutil.T, meters []skaffoldMeter, b []byte) {
 				buildDeps[k] += v
 			}
 		}
-		if meter.Command == "dev" {
+		if meter.Command == "dev" || meter.Command == "debug" {
 			for _, devI := range meter.DevIterations {
 				devIterations[devI]++
 			}
@@ -293,18 +318,20 @@ func checkOutput(t *testutil.T, meters []skaffoldMeter, b []byte) {
 			builders[l.Labels["builder"]]--
 		case "deployer":
 			deployers[l.Labels["deployer"]]--
-		case "dev/iterations":
+		case "dev/iterations", "debug/iterations":
 			e := l.Labels["error"]
 			devIterations[devIteration{l.Labels["intent"], proto.StatusCode(proto.StatusCode_value[e])}]--
 		case "errors":
 			e := l.Labels["error"]
 			errorCount[e]--
+		case "flags":
+			enumFlags[l.Labels["flag_name"]+":"+l.Labels["value"]]--
+		case "helmReleases":
+			helmReleases[l.Labels["helmReleases"]]++
 		default:
 			switch {
-			case meteredCommands.Contains(l.Name):
+			case MeteredCommands.Contains(l.Name):
 				commandCount[l.Name]--
-			case strings.HasPrefix(l.Name, "flags/"):
-				enumFlags[l.Name+":"+l.Labels["value"]]--
 			default:
 				t.Error("unexpected metric with name", l.Name)
 			}
