@@ -174,7 +174,7 @@ func (rc *RunContext) MinikubeProfile() string                   { return rc.Opt
 func (rc *RunContext) Muted() config.Muted                       { return rc.Opts.Muted }
 func (rc *RunContext) NoPruneChildren() bool                     { return rc.Opts.NoPruneChildren }
 func (rc *RunContext) Notification() bool                        { return rc.Opts.Notification }
-func (rc *RunContext) PortForward() bool                         { return rc.Opts.PortForward.Enabled }
+func (rc *RunContext) PortForward() bool                         { return rc.Opts.PortForward.Enabled() }
 func (rc *RunContext) Prune() bool                               { return rc.Opts.Prune() }
 func (rc *RunContext) RenderOnly() bool                          { return rc.Opts.RenderOnly }
 func (rc *RunContext) RenderOutput() string                      { return rc.Opts.RenderOutput }
