@@ -65,13 +65,12 @@ profiles:
 
 		parsed, err := ParseConfig(tmpDir.Path("skaffold.yaml"))
 		t.CheckNoError(err)
+		t.CheckTrue(len(parsed) > 0)
 
-		skaffoldConfig := parsed.(*latest.SkaffoldConfig)
-		err = ApplyProfiles(skaffoldConfig, cfg.SkaffoldOptions{
-			Profiles: []string{"patches"},
-		})
-
+		skaffoldConfig := parsed[0].(*latest.SkaffoldConfig)
+		activated, err := ApplyProfiles(skaffoldConfig, cfg.SkaffoldOptions{}, []string{"patches"})
 		t.CheckNoError(err)
+		t.CheckDeepEqual([]string{"patches"}, activated)
 		t.CheckDeepEqual("replacement", skaffoldConfig.Build.Artifacts[0].ImageName)
 		t.CheckDeepEqual("Dockerfile.DEV", skaffoldConfig.Build.Artifacts[0].DockerArtifact.DockerfilePath)
 		t.CheckDeepEqual("Dockerfile.second", skaffoldConfig.Build.Artifacts[1].DockerArtifact.DockerfilePath)
@@ -96,12 +95,10 @@ profiles:
 
 		parsed, err := ParseConfig(tmp.Path("skaffold.yaml"))
 		t.CheckNoError(err)
+		t.CheckTrue(len(parsed) > 0)
 
-		skaffoldConfig := parsed.(*latest.SkaffoldConfig)
-		err = ApplyProfiles(skaffoldConfig, cfg.SkaffoldOptions{
-			Profiles: []string{"patches"},
-		})
-
+		skaffoldConfig := parsed[0].(*latest.SkaffoldConfig)
+		_, err = ApplyProfiles(skaffoldConfig, cfg.SkaffoldOptions{}, []string{"patches"})
 		t.CheckErrorAndDeepEqual(true, err, `applying profile "patches": invalid path: /build/artifacts/0/image/`, err.Error())
 	})
 }
@@ -488,11 +485,11 @@ func TestApplyProfiles(t *testing.T) {
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
 			setupFakeKubeConfig(t, api.Config{CurrentContext: "prod-context"})
-			err := ApplyProfiles(test.config, cfg.SkaffoldOptions{
-				Profiles:              []string{test.profile},
+			_, err := ApplyProfiles(test.config, cfg.SkaffoldOptions{
+				Command:               "dev",
 				KubeContext:           test.kubeContextCli,
 				ProfileAutoActivation: test.profileAutoActivationCli,
-			})
+			}, []string{test.profile})
 
 			if test.shouldErr {
 				t.CheckError(test.shouldErr, err)
@@ -555,6 +552,20 @@ func TestActivatedProfiles(t *testing.T) {
 				{Name: "regex-activated-substring-match", Activation: []latest.Activation{{Env: "KEY=^VAL"}}},
 			},
 			expected: []string{"activated", "also-activated", "regex-activated", "regex-activated-two", "regex-activated-substring-match"},
+		}, {
+			description: "Profile with multiple valid activations",
+			envs:        map[string]string{"KEY": "VALUE"},
+			opts: cfg.SkaffoldOptions{
+				ProfileAutoActivation: true,
+				Command:               "dev",
+				Profiles:              []string{"activated", "also-activated"},
+			},
+			profiles: []latest.Profile{
+				{Name: "activated", Activation: []latest.Activation{{Env: "KEY=VALUE"}, {Command: "dev"}}},
+				{Name: "not-activated", Activation: []latest.Activation{{Env: "KEY=OTHER"}}},
+				{Name: "also-activated", Activation: []latest.Activation{{Env: "KEY=!OTHER"}}},
+			},
+			expected: []string{"activated", "also-activated"},
 		}, {
 			description: "Invalid env variable",
 			envs:        map[string]string{"KEY": "VALUE"},
@@ -751,7 +762,7 @@ func TestActivatedProfiles(t *testing.T) {
 			t.SetEnvs(test.envs)
 			t.SetupFakeKubernetesContext(api.Config{CurrentContext: "prod-context"})
 
-			activated, _, err := activatedProfiles(test.profiles, test.opts)
+			activated, _, err := activatedProfiles(test.profiles, test.opts, test.opts.Profiles)
 
 			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.expected, activated)
 		})
@@ -788,8 +799,9 @@ profiles:
 
 		parsed, err := ParseConfig(tmpDir.Path("skaffold.yaml"))
 		t.RequireNoError(err)
+		t.CheckTrue(len(parsed) > 0)
 
-		skaffoldConfig := parsed.(*latest.SkaffoldConfig)
+		skaffoldConfig := parsed[0].(*latest.SkaffoldConfig)
 
 		t.CheckDeepEqual(2, len(skaffoldConfig.Profiles))
 		t.CheckDeepEqual("simple1", skaffoldConfig.Profiles[0].Name)
@@ -797,11 +809,9 @@ profiles:
 		t.CheckDeepEqual("simple2", skaffoldConfig.Profiles[1].Name)
 		t.CheckDeepEqual([]latest.Activation{{Env: "ABC=common"}, {Env: "ABC=2"}}, skaffoldConfig.Profiles[1].Activation)
 
-		err = ApplyProfiles(skaffoldConfig, cfg.SkaffoldOptions{
-			Profiles: []string{"simple1"},
-		})
+		applied, err := ApplyProfiles(skaffoldConfig, cfg.SkaffoldOptions{}, []string{"simple1"})
 		t.CheckNoError(err)
-
+		t.CheckDeepEqual([]string{"simple1"}, applied)
 		t.CheckDeepEqual(1, len(skaffoldConfig.Build.Artifacts))
 		t.CheckDeepEqual(latest.Artifact{ImageName: "simpleimage1"}, *skaffoldConfig.Build.Artifacts[0])
 	})
