@@ -26,6 +26,7 @@ import (
 
 	"github.com/sirupsen/logrus"
 
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 )
 
@@ -60,8 +61,8 @@ func NewGitCommit(prefix, variant string, ignoreChanges bool) (*GitCommit, error
 }
 
 // GenerateTag generates a tag from the git commit.
-func (t *GitCommit) GenerateTag(workingDir, _ string) (string, error) {
-	ref, err := t.runGitFn(workingDir)
+func (t *GitCommit) GenerateTag(image latest.Artifact) (string, error) {
+	ref, err := t.runGitFn(image.Workspace)
 	if err != nil {
 		return "", fmt.Errorf("unable to find git commit: %w", err)
 	}
@@ -69,7 +70,7 @@ func (t *GitCommit) GenerateTag(workingDir, _ string) (string, error) {
 	ref = sanitizeTag(ref)
 
 	if !t.ignoreChanges {
-		changes, err := runGit(workingDir, "status", ".", "--porcelain")
+		changes, err := runGit(image.Workspace, "status", ".", "--porcelain")
 		if err != nil {
 			return "", fmt.Errorf("getting git status: %w", err)
 		}
